@@ -63,13 +63,13 @@ buildSplicedSevdist <- function(body.distr, body.param, tail.distr, tail.param,
   
   parlist[[1]][[1]]=function(x){ifelse(x>thresh, evaluate("d", tail.distr, tail.param, x)/(1-evaluate("p", tail.distr, tail.param, thresh)), 0)}
   parlist[[1]][[2]]=function(q){ifelse(q>thresh, (evaluate("p", tail.distr, tail.param, q) -  evaluate("p", tail.distr, tail.param, thresh)) /(1-evaluate("p", tail.distr, tail.param, thresh)),0)}
-  parlist[[1]][[3]]=function(p){ifelse(p>weight, evaluate("q", tail.distr, tail.param, evaluate("p", tail.distr, tail.param, thresh) + p*(1-evaluate("p", tail.distr, tail.param, thresh))),0)}
+  parlist[[1]][[3]]=function(p){ifelse(p>weight, evaluate("q", tail.distr, tail.param, evaluate("p", tail.distr, tail.param, thresh) + (p-weight)*(1-evaluate("p", tail.distr, tail.param, thresh))/(1-weight)),0)}
   parlist[[1]][[5]]=tail.param
   parlist[[1]][[6]]=tail.distr
   
   parlist[[2]][[1]]=function(x){ifelse(x<=thresh, evaluate("d", body.distr, body.param, x)/evaluate("p", body.distr, body.param, thresh), 0)}
   parlist[[2]][[2]]=function(q){ifelse(q<=thresh, evaluate("p", body.distr, body.param, q)/evaluate("p", body.distr, body.param, thresh),0)}
-  parlist[[2]][[3]]=function(p){ifelse(p<=weight, evaluate("q", body.distr, body.param, p*evaluate("p", body.distr, body.param, thresh)), 0)}
+  parlist[[2]][[3]]=function(p){ifelse(p<=weight, evaluate("q", body.distr, body.param, p*evaluate("p", body.distr, body.param, thresh)/ weight), 0)}
   parlist[[2]][[5]]=body.param
   parlist[[2]][[6]]=body.distr
   
@@ -78,4 +78,4 @@ buildSplicedSevdist <- function(body.distr, body.param, tail.distr, tail.param,
   sevdist$weights = c(weight, 1-weight)
   class(sevdist)="sevdist"
   return(sevdist) 
-}
\ No newline at end of file
+}
